package com.ruoyi.system.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.ruoyi.system.mapper.PosFreightMapper;
import com.ruoyi.system.domain.PosFreight;
import com.ruoyi.system.service.IPosFreightService;

/**
 * freightService业务层处理
 * 
 * @author ruoyi
 * @date 2023-07-15
 */
@Service
public class PosFreightServiceImpl extends ServiceImpl<BaseMapper<PosFreight>,PosFreight> implements IPosFreightService
{
    @Autowired
    private PosFreightMapper posFreightMapper;

    /**
     * 查询freight
     * 
     * @param id freight主键
     * @return freight
     */
    @Override
    public PosFreight selectPosFreightById(Long id)
    {
        return posFreightMapper.selectPosFreightById(id);
    }

    /**
     * 查询freight列表
     * 
     * @param posFreight freight
     * @return freight
     */
    @Override
    public List<PosFreight> selectPosFreightList(PosFreight posFreight)
    {
        return posFreightMapper.selectPosFreightList(posFreight);
    }

    /**
     * 新增freight
     * 
     * @param posFreight freight
     * @return 结果
     */
    @Override
    public int insertPosFreight(PosFreight posFreight)
    {
        return posFreightMapper.insertPosFreight(posFreight);
    }

    /**
     * 修改freight
     * 
     * @param posFreight freight
     * @return 结果
     */
    @Override
    public int updatePosFreight(PosFreight posFreight)
    {
        return posFreightMapper.updatePosFreight(posFreight);
    }

    /**
     * 批量删除freight
     * 
     * @param ids 需要删除的freight主键
     * @return 结果
     */
    @Override
    public int deletePosFreightByIds(Long[] ids)
    {
        return posFreightMapper.deletePosFreightByIds(ids);
    }

    /**
     * 删除freight信息
     * 
     * @param id freight主键
     * @return 结果
     */
    @Override
    public int deletePosFreightById(Long id)
    {
        return posFreightMapper.deletePosFreightById(id);
    }
}
